==> igniteui-react-charts-16.4.1.tgz: package/ES5/CategoryHighlightLayer_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { AnnotationLayer } from "./AnnotationLayer";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { CategoryHighlightLayerFrame } from "./CategoryHighlightLayerFrame";
import { Type, Base, Number_$type, typeCast, fromEnum, Point_$type, markType, runOn } from "igniteui-react-core/ES5/type";
import { XamDataChart } from "./XamDataChart";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { CategoryHighlightFrameRect } from "./CategoryHighlightFrameRect";
import { Pool$1 } from "igniteui-react-core/ES5/Pool$1";
import { Rectangle } from "igniteui-react-core/ES5/Rectangle";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { isNaN_, truncate } from "igniteui-react-core/ES5/number";
import { AnnotationLayerView } from "./AnnotationLayerView";
import { BrushUtil } from "igniteui-react-core/ES5/BrushUtil";
import { Color } from "igniteui-react-core/ES5/Color";
var CategoryHighlightLayer = /** @class */ (function (_super) {
    tslib_1.__extends(CategoryHighlightLayer, _super);
    function CategoryHighlightLayer() {
        var _this = _super.call(this) || this;
        var a = new CategoryHighlightLayerFrame();
        var b = new CategoryHighlightLayerFrame();
        var c = new CategoryHighlightLayerFrame();
        var d = _this.fe / 1000;
        _this.lt = a;
        _this.ls = b;
        _this.lu = c;
        _this.ab = CategoryHighlightLayer.$;
        return _this;
    }
    CategoryHighlightLayer.prototype.bf = function () {
        return new CategoryHighlightLayerView(this);
    };
    CategoryHighlightLayer.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.mu = a;
    };
    Object.defineProperty(CategoryHighlightLayer.prototype, "mx", {
        get: function () {
            return this.c(CategoryHighlightLayer.m4);
        },
        set: function (a) {
            this.h(CategoryHighlightLayer.m4, a);
        },
        enumerable: true,
        configurable: true
    });
    CategoryHighlightLayer.prototype.l9 = function (a, b) {
        if (this.mt == null || this.mt == a) {
            if (!this.aq.c) {
                this.i4(b);
            }
        }
    };
    CategoryHighlightLayer.prototype.mv = function (a) {
        return a != null && a.cd();
    };
    CategoryHighlightLayer.prototype.mc = function (a, b) {
        var e_1, _a;
        _super.prototype.mc.call(this, a, b);
        var c = a;
        c.g.clear();
        var d = this.mw;
        if (isNaN_(this.mq.x) && isNaN_(this.mq.y)) {
            return;
        }
        if (this.mt != null) {
            if (this.mv(this.mt)) {
                this.m2(this.mt, c, d);
            }
        }
        else {
            if (typeCast(XamDataChart.$, this.bs) !== null) {
                var e = this.bs;
                try {
                    for (var _b = tslib_1.__values(fromEnum(e.axes)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var f = _c.value;
                        if (typeCast(CategoryAxisBase.$, f) !== null && this.mv(f)) {
                            this.m2(f, c, d);
                        }
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
        }
    };
    CategoryHighlightLayer.prototype.m2 = function (a, b, c) {
        if (this.bi == null || this.bi.bq.isEmpty || this.bi.bp.isEmpty) {
            return;
        }
        var d = this.mq.x;
        if (a.ce && isNaN_(d)) {
            d = 0;
        }
        d = this.bi.bp.left + this.bi.bp.width * (d - this.bi.bq.left) / this.bi.bq.width;
        var e = this.mq.y;
        if (!a.ce && isNaN_(e)) {
            e = 0;
        }
        e = this.bi.bp.top + this.bi.bp.height * (e - this.bi.bq.top) / this.bi.bq.height;
        var f = a.kn({ $type: Point_$type, x: d, y: e }, c, this.mx);
        this.m1(f, b, a);
    };
    CategoryHighlightLayer.prototype.m1 = function (a, b, c) {
        var d = new CategoryHighlightFrameRect();
        d.b = a.left;
        d.e = a.top;
        d.c = a.right;
        d.a = a.bottom;
        d.g = this.mo();
        d.h = this.mp();
        if (d.g == null) {
            d.g = this.mu.b7(c.ib);
        }
        if (d.h == null) {
            d.h = this.mu.b7(c.ib);
        }
        d.d = this.eu;
        d.f = Base.getHashCodeStatic(c);
        if (!a.isEmpty) {
            b.g.addItem(d.f, d);
        }
    };
    CategoryHighlightLayer.prototype.mf = function (a, b) {
        var e_2, _a;
        _super.prototype.mf.call(this, a, b);
        var c = this.mu.b0;
        var d = a;
        var e = 0;
        try {
            for (var _b = tslib_1.__values(fromEnum(d.g.values)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var f = _c.value;
                var g = c.item(e);
                this.m3(f, g);
                e++;
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_2) throw e_2.error; }
        }
        c.count = e;
    };
    CategoryHighlightLayer.prototype.c6 = function () {
        return true;
    };
    CategoryHighlightLayer.prototype.m3 = function (a, b) {
        if (isNaN_(a.b) || isNaN_(a.e) || isNaN_(a.a) || isNaN_(a.c) || isNaN_(a.d)) {
            b._visibility = 1;
            return;
        }
        this.mu.b2(b, a.b, a.e, a.c - a.b, a.a - a.e);
        b._fill = a.g;
        b._stroke = a.h;
        b.ac = a.d;
        if (this.k2 != null) {
            b.ai = this.k2;
        }
        else {
            b.ai = null;
        }
        b.ad = this.k3;
    };
    CategoryHighlightLayer.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case CategoryHighlightLayer.$$p[0]:
                this.i4(true);
                break;
            case CategoryHighlightLayer.$$p[1]:
                this.i4(true);
                break;
        }
    };
    CategoryHighlightLayer.m4 = DependencyProperty.i("BAndHighlightWidth", Number_$type, CategoryHighlightLayer.$, new PropertyMetadata(2, 10, function (a, b) { return a.raisePropertyChanged("BAndHighlightWidth", b.oldValue, b.newValue); }));
    CategoryHighlightLayer.$t = markType(CategoryHighlightLayer, 'CategoryHighlightLayer', AnnotationLayer.$);
    return CategoryHighlightLayer;
}(AnnotationLayer));
export { CategoryHighlightLayer };
Type.dep(DependencyProperty, PropertyMetadata, CategoryHighlightLayer, 'raisePropertyChanged', ['TargetAxis:mt:m5', [CategoryAxisBase.$, null], 'UseInterpolation:mw:m6', [0, false]]);
var CategoryHighlightLayerView = /** @class */ (function (_super) {
    tslib_1.__extends(CategoryHighlightLayerView, _super);
    function CategoryHighlightLayerView(a) {
        var _this = _super.call(this, a) || this;
        _this.bz = null;
        _this.b0 = null;
        _this.b1 = null;
        _this.bz = a;
        _this.b1 = new List$1(Rectangle.$, 0);
        return _this;
    }
    CategoryHighlightLayerView.prototype.ap = function () {
        var _this = this;
        _super.prototype.ap.call(this);
        this.b0 = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.b8);
            $ret.activate = runOn(_this, _this.b3);
            $ret.disactivate = runOn(_this, _this.b5);
            $ret.destroy = runOn(_this, _this.b4);
            return $ret;
        })());
    };
    CategoryHighlightLayerView.prototype.b8 = function () {
        var a = new Rectangle();
        a.ab = false;
        this.b1.add(a);
        return a;
    };
    CategoryHighlightLayerView.prototype.b3 = function (a) {
        a._visibility = 0;
    };
    CategoryHighlightLayerView.prototype.b5 = function (a) {
        a._visibility = 1;
    };
    CategoryHighlightLayerView.prototype.b4 = function (a) {
        this.b1.remove(a);
    };
    CategoryHighlightLayerView.prototype.b6 = function (a) {
        if (a == null) {
            return a;
        }
        return BrushUtil.h(a, 0.1);
    };
    CategoryHighlightLayerView.prototype.b7 = function (a) {
        if (a != null) {
            var b = BrushUtil.h(a, 0.3);
            if (b.isGradient) {
                var c = b;
                if (c.gradientStops != null) {
                    for (var d = 0; d < c.gradientStops.length; d++) {
                        var e = c.gradientStops[d];
                        e.color = Color.u(truncate(Math.round((e.color.l) * 0.2)), e.color.o, e.color.n, e.color.m);
                        e.color = e.color;
                    }
                }
            }
            else {
                b.color = Color.u(truncate(Math.round((b.color.l) * 0.2)), b.color.o, b.color.n, b.color.m);
                b.color = b.color;
            }
            return b;
        }
        else {
            return null;
        }
    };
    CategoryHighlightLayerView.prototype.b2 = function (a, b, c, d, e) {
        a._visibility = 0;
        a.n = b;
        a.o = c;
        a.width = d;
        a.height = e;
    };
    CategoryHighlightLayerView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d && !b) {
            for (var c = 0; c < this.b1.count; c++) {
                var d = this.b1._inner[c];
                if (d._visibility == 0) {
                    a.v(d);
                }
            }
        }
    };
    CategoryHighlightLayerView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        for (var b = 0; b < this.b1.count; b++) {
            this.e.a2.exportRectangleData(a, this.b1._inner[b], "cihRect", ["Main", "CategoryItem"]);
        }
    };
    CategoryHighlightLayerView.$t = markType(CategoryHighlightLayerView, 'CategoryHighlightLayerView', AnnotationLayerView.$);
    return CategoryHighlightLayerView;
}(AnnotationLayerView));
export { CategoryHighlightLayerView };
/*<BeginStatics Name="Infragistics.Controls.Charts.CategoryHighlightLayer" />*/
/*<EndStatics Name="Infragistics.Controls.Charts.CategoryHighlightLayer" />*/

==> igniteui-react-charts-16.6.4.tgz: package/ES5/CategoryHighlightLayer_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { AnnotationLayer } from "./AnnotationLayer";
import { CategoryAxisBase } from "./CategoryAxisBase";
import { DependencyProperty } from "igniteui-react-core/ES5/DependencyProperty";
import { CategoryHighlightLayerFrame } from "./CategoryHighlightLayerFrame";
import { Type, Base, Number_$type, typeCast, fromEnum, Point_$type, markType, runOn } from "igniteui-react-core/ES5/type";
import { XamDataChart } from "./XamDataChart";
import { CategoryHighlightFrameRect } from "./CategoryHighlightFrameRect";
import { List$1 } from "igniteui-react-core/ES5/List$1";
import { Pool$1 } from "igniteui-react-core/ES5/Pool$1";
import { Rectangle } from "igniteui-react-core/ES5/Rectangle";
import { PropertyMetadata } from "igniteui-react-core/ES5/PropertyMetadata";
import { isNaN_, truncate } from "igniteui-react-core/ES5/number";
import { AnnotationLayerView } from "./AnnotationLayerView";
import { BrushUtil } from "igniteui-react-core/ES5/BrushUtil";
import { Color } from "igniteui-react-core/ES5/Color";
var CategoryHighlightLayer = /** @class */ (function (_super) {
    tslib_1.__extends(CategoryHighlightLayer, _super);
    function CategoryHighlightLayer() {
        var _this = _super.call(this) || this;
        var a = new CategoryHighlightLayerFrame();
        var b = new CategoryHighlightLayerFrame();
        var c = new CategoryHighlightLayerFrame();
        var d = _this.fe / 1000;
        _this.lt = a;
        _this.ls = b;
        _this.lu = c;
        _this.ab = CategoryHighlightLayer.$;
        return _this;
    }
    CategoryHighlightLayer.prototype.bf = function () {
        return new CategoryHighlightLayerView(this);
    };
    CategoryHighlightLayer.prototype.il = function (a) {
        _super.prototype.il.call(this, a);
        this.mu = a;
    };
    Object.defineProperty(CategoryHighlightLayer.prototype, "mx", {
        get: function () {
            return this.c(CategoryHighlightLayer.m4);
        },
        set: function (a) {
            this.h(CategoryHighlightLayer.m4, a);
        },
        enumerable: true,
        configurable: true
    });
    CategoryHighlightLayer.prototype.l9 = function (a, b) {
        if (this.mt == null || this.mt == a) {
            if (!this.aq.c) {
                this.i4(b);
            }
        }
    };
    CategoryHighlightLayer.prototype.mv = function (a) {
        return a != null && a.cd();
    };
    CategoryHighlightLayer.prototype.mc = function (a, b) {
        var e_1, _a;
        _super.prototype.mc.call(this, a, b);
        var c = a;
        c.g.clear();
        var d = this.mw;
        if (isNaN_(this.mq.x) && isNaN_(this.mq.y)) {
            return;
        }
        if (this.mt != null) {
            if (this.mv(this.mt)) {
                this.m2(this.mt, c, d);
            }
        }
        else {
            if (typeCast(XamDataChart.$, this.bs) !== null) {
                var e = this.bs;
                try {
                    for (var _b = tslib_1.__values(fromEnum(e.axes)), _c = _b.next(); !_c.done; _c = _b.next()) {
                        var f = _c.value;
                        if (typeCast(CategoryAxisBase.$, f) !== null && this.mv(f)) {
                            this.m2(f, c, d);
                        }
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
        }
    };
    CategoryHighlightLayer.prototype.m2 = function (a, b, c) {
        if (this.bi == null || this.bi.bs.isEmpty || this.bi.br.isEmpty) {
            return;
        }
        var d = this.mq.x;
        if (a.ce && isNaN_(d)) {
            d = 0;
        }
        d = this.bi.br.left + this.bi.br.width * (d - this.bi.bs.left) / this.bi.bs.width;
        var e = this.mq.y;
        if (!a.ce && isNaN_(e)) {
            e = 0;
        }
        e = this.bi.br.top + this.bi.br.height * (e - this.bi.bs.top) / this.bi.bs.height;
        var f = a.kn({ $type: Point_$type, x: d, y: e }, c, this.mx);
        this.m1(f, b, a);
    };
    CategoryHighlightLayer.prototype.m1 = function (a, b, c) {
        var d = new CategoryHighlightFrameRect();
        d.b = a.left;
        d.e = a.top;
        d.c = a.right;
        d.a = a.bottom;
        d.g = this.mo();
        d.h = this.mp();
        if (d.g == null) {
            d.g = this.mu.b9(c.ib);
        }
        if (d.h == null) {
            d.h = this.mu.b9(c.ib);
        }
        d.d = this.eu;
        d.f = Base.getHashCodeStatic(c);
        if (!a.isEmpty) {
            b.g.addItem(d.f, d);
        }
    };
    CategoryHighlightLayer.prototype.mf = function (a, b) {
        var e_2, _a;
        _super.prototype.mf.call(this, a, b);
        var c = this.mu.b2;
        var d = a;
        var e = 0;
        try {
            for (var _b = tslib_1.__values(fromEnum(d.g.values)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var f = _c.value;
                var g = c.item(e);
                this.m3(f, g);
                e++;
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_2) throw e_2.error; }
        }
        c.count = e;
    };
    CategoryHighlightLayer.prototype.c6 = function () {
        return true;
    };
    CategoryHighlightLayer.prototype.m3 = function (a, b) {
        if (isNaN_(a.b) || isNaN_(a.e) || isNaN_(a.a) || isNaN_(a.c) || isNaN_(a.d)) {
            b._visibility = 1;
            return;
        }
        this.mu.b4(b, a.b, a.e, a.c - a.b, a.a - a.e);
        b._fill = a.g;
        b._stroke = a.h;
        b.ac = a.d;
        if (this.k2 != null) {
            b.ai = this.k2;
        }
        else {
            b.ai = null;
        }
        b.ad = this.k3;
    };
    CategoryHighlightLayer.prototype.ir = function (a, b, c, d) {
        _super.prototype.ir.call(this, a, b, c, d);
        switch (b) {
            case CategoryHighlightLayer.$$p[0]:
                this.i4(true);
                break;
            case CategoryHighlightLayer.$$p[1]:
                this.i4(true);
                break;
        }
    };
    CategoryHighlightLayer.$t = markType(CategoryHighlightLayer, 'CategoryHighlightLayer', AnnotationLayer.$);
    CategoryHighlightLayer.m4 = DependencyProperty.i("BAndHighlightWidth", Number_$type, CategoryHighlightLayer.$, new PropertyMetadata(2, 10, function (a, b) { return a.raisePropertyChanged("BAndHighlightWidth", b.oldValue, b.newValue); }));
    return CategoryHighlightLayer;
}(AnnotationLayer));
export { CategoryHighlightLayer };
Type.dep(DependencyProperty, PropertyMetadata, CategoryHighlightLayer, 'raisePropertyChanged', ['TargetAxis:mt:m5', [CategoryAxisBase.$, null], 'UseInterpolation:mw:m6', [0, false]]);
var CategoryHighlightLayerView = /** @class */ (function (_super) {
    tslib_1.__extends(CategoryHighlightLayerView, _super);
    function CategoryHighlightLayerView(a) {
        var _this = _super.call(this, a) || this;
        _this.b1 = null;
        _this.b2 = null;
        _this.b3 = null;
        _this.b1 = a;
        _this.b3 = new List$1(Rectangle.$, 0);
        return _this;
    }
    CategoryHighlightLayerView.prototype.ap = function () {
        var _this = this;
        _super.prototype.ap.call(this);
        this.b2 = ((function () {
            var $ret = new Pool$1(Rectangle.$);
            $ret.create = runOn(_this, _this.ca);
            $ret.activate = runOn(_this, _this.b5);
            $ret.disactivate = runOn(_this, _this.b7);
            $ret.destroy = runOn(_this, _this.b6);
            return $ret;
        })());
    };
    CategoryHighlightLayerView.prototype.ca = function () {
        var a = new Rectangle();
        a.ab = false;
        this.b3.add(a);
        return a;
    };
    CategoryHighlightLayerView.prototype.b5 = function (a) {
        a._visibility = 0;
    };
    CategoryHighlightLayerView.prototype.b7 = function (a) {
        a._visibility = 1;
    };
    CategoryHighlightLayerView.prototype.b6 = function (a) {
        this.b3.remove(a);
    };
    CategoryHighlightLayerView.prototype.b8 = function (a) {
        if (a == null) {
            return a;
        }
        return BrushUtil.h(a, 0.1);
    };
    CategoryHighlightLayerView.prototype.b9 = function (a) {
        if (a != null) {
            var b = BrushUtil.h(a, 0.3);
            if (b.isGradient) {
                var c = b;
                if (c.gradientStops != null) {
                    for (var d = 0; d < c.gradientStops.length; d++) {
                        var e = c.gradientStops[d];
                        e.color = Color.u(truncate(Math.round((e.color.l) * 0.2)), e.color.o, e.color.n, e.color.m);
                        e.color = e.color;
                    }
                }
            }
            else {
                b.color = Color.u(truncate(Math.round((b.color.l) * 0.2)), b.color.o, b.color.n, b.color.m);
                b.color = b.color;
            }
            return b;
        }
        else {
            return null;
        }
    };
    CategoryHighlightLayerView.prototype.b4 = function (a, b, c, d, e) {
        a._visibility = 0;
        a.n = b;
        a.o = c;
        a.width = d;
        a.height = e;
    };
    CategoryHighlightLayerView.prototype.a3 = function (a, b) {
        _super.prototype.a3.call(this, a, b);
        if (a.d && !b) {
            for (var c = 0; c < this.b3.count; c++) {
                var d = this.b3._inner[c];
                if (d._visibility == 0) {
                    a.v(d);
                }
            }
        }
    };
    CategoryHighlightLayerView.prototype.ai = function (a) {
        _super.prototype.ai.call(this, a);
        for (var b = 0; b < this.b3.count; b++) {
            this.e.a2.exportRectangleData(a, this.b3._inner[b], "cihRect", ["Main", "CategoryItem"]);
        }
    };
    CategoryHighlightLayerView.$t = markType(CategoryHighlightLayerView, 'CategoryHighlightLayerView', AnnotationLayerView.$);
    return CategoryHighlightLayerView;
}(AnnotationLayerView));
export { CategoryHighlightLayerView };
